"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DrupalError = void 0;
/**
 * Constructs a new Drupal.Error object with the given code and message.
 */
class DrupalError extends Error {
    /**
     * @param {number} code An error code constant from <code>Drupal.Error</code>.
     * @param {string} message A detailed description of the error.
     */
    constructor(code, message) {
        super(message);
        this.code = code;
        Object.defineProperty(this, 'message', {
            enumerable: true,
            value: message,
        });
    }
    /**
     * Get the error code.
     * @returns error code.
     */
    getErrorCode() {
        return this.code;
    }
    /**
     * Drupal error message.
     * @returns Error message.
     */
    toString() {
        return `DrupalError: ${this.code} ${this.message}`;
    }
}
exports.DrupalError = DrupalError;
/**
 * Error code indicating some error other than those enumerated here.
 */
DrupalError.UNDEFINED = -1;
/**
 * Error code indicating that something has gone wrong with the server.
 */
DrupalError.INTERNAL_SERVER_ERROR = 1;
/**
 * Error code indicating the sdk has encountered a missing implementation.
 */
DrupalError.MISSING_IMPLEMENTATION_ERROR = 42;
/**
 * Error code indicating the connection to the Drupal server failed.
 */
DrupalError.CONNECTION_FAILED = 100;
/**
 * Error code indicating the specified object doesn't exist.
 */
DrupalError.OBJECT_NOT_FOUND = 101;
/**
 * Error code indicating you tried to query with a datatype that doesn't
 * support it, like exact matching an array or object.
 */
DrupalError.INVALID_QUERY = 102;
/**
 * Error code indicating a missing or invalid classname. Classnames are
 * case-sensitive. They must start with a letter, and a-zA-Z0-9_ are the
 * only valid characters.
 */
DrupalError.INVALID_CLASS_NAME = 103;
/**
 * Error code indicating an unspecified object id.
 */
DrupalError.MISSING_OBJECT_ID = 104;
/**
 * Error code indicating an invalid key name. Keys are case-sensitive. They
 * must start with a letter, and a-zA-Z0-9_ are the only valid characters.
 */
DrupalError.INVALID_KEY_NAME = 105;
/**
 * Error code indicating a malformed pointer. You should not see this unless
 * you have been mucking about changing internal Drupal code.
 */
DrupalError.INVALID_POINTER = 106;
/**
 * Error code indicating that badly formed JSON was received upstream. This
 * either indicates you have done something unusual with modifying how
 * things encode to JSON, or the network is failing badly.
 */
DrupalError.INVALID_JSON = 107;
/**
 * Error code indicating that the feature you tried to access is only
 * available internally for testing purposes.
 */
DrupalError.COMMAND_UNAVAILABLE = 108;
/**
 * You must call Drupal.initialize before using the Drupal library.
 */
DrupalError.NOT_INITIALIZED = 109;
/**
 * Error code indicating that a field was set to an inconsistent type.
 */
DrupalError.INCORRECT_TYPE = 111;
/**
 * Error code indicating an invalid channel name. A channel name is either
 * an empty string (the broadcast channel) or contains only a-zA-Z0-9_
 * characters and starts with a letter.
 */
DrupalError.INVALID_CHANNEL_NAME = 112;
/**
 * Error code indicating that push is misconfigured.
 */
DrupalError.PUSH_MISCONFIGURED = 115;
/**
 * Error code indicating that the object is too large.
 */
DrupalError.OBJECT_TOO_LARGE = 116;
/**
 * Error code indicating that the operation isn't allowed for clients.
 */
DrupalError.OPERATION_FORBIDDEN = 119;
/**
 * Error code indicating the result was not found in the cache.
 */
DrupalError.CACHE_MISS = 120;
/**
 * Error code indicating that an invalid key was used in a nested
 * JSONObject.
 */
DrupalError.INVALID_NESTED_KEY = 121;
/**
 * Error code indicating that an invalid filename was used for DrupalFile.
 * A valid file name contains only a-zA-Z0-9_. characters and is between 1
 * and 128 characters.
 */
DrupalError.INVALID_FILE_NAME = 122;
/**
 * Error code indicating an invalid ACL was provided.
 */
DrupalError.INVALID_ACL = 123;
/**
 * Error code indicating that the request timed out on the server. Typically
 * this indicates that the request is too expensive to run.
 */
DrupalError.TIMEOUT = 124;
/**
 * Error code indicating that the email address was invalid.
 */
DrupalError.INVALID_EMAIL_ADDRESS = 125;
/**
 * Error code indicating a missing content type.
 */
DrupalError.MISSING_CONTENT_TYPE = 126;
/**
 * Error code indicating a missing content length.
 */
DrupalError.MISSING_CONTENT_LENGTH = 127;
/**
 * Error code indicating an invalid content length.
 */
DrupalError.INVALID_CONTENT_LENGTH = 128;
/**
 * Error code indicating a file that was too large.
 */
DrupalError.FILE_TOO_LARGE = 129;
/**
 * Error code indicating an error saving a file.
 */
DrupalError.FILE_SAVE_ERROR = 130;
/**
 * Error code indicating that a unique field was given a value that is
 * already taken.
 */
DrupalError.DUPLICATE_VALUE = 137;
/**
 * Error code indicating that a role's name is invalid.
 */
DrupalError.INVALID_ROLE_NAME = 139;
/**
 * Error code indicating that an application quota was exceeded.  Upgrade to
 * resolve.
 */
DrupalError.EXCEEDED_QUOTA = 140;
/**
 * Error code indicating that a Cloud Code script failed.
 */
DrupalError.SCRIPT_FAILED = 141;
/**
 * Error code indicating that a Cloud Code validation failed.
 */
DrupalError.VALIDATION_ERROR = 142;
/**
 * Error code indicating that invalid image data was provided.
 */
DrupalError.INVALID_IMAGE_DATA = 143;
/**
 * Error code indicating an unsaved file.
 */
DrupalError.UNSAVED_FILE_ERROR = 151;
/**
 * Error code indicating an invalid push time.
 */
DrupalError.INVALID_PUSH_TIME_ERROR = 152;
/**
 * Error code indicating an error deleting a file.
 */
DrupalError.FILE_DELETE_ERROR = 153;
/**
 * Error code indicating an error deleting an unnamed file.
 */
DrupalError.FILE_DELETE_UNNAMED_ERROR = 161;
/**
 * Error code indicating that the application has exceeded its request
 * limit.
 */
DrupalError.REQUEST_LIMIT_EXCEEDED = 155;
/**
 * Error code indicating that the request was a duplicate and has been discarded due to
 * idempotency rules.
 */
DrupalError.DUPLICATE_REQUEST = 159;
/**
 * Error code indicating an invalid event name.
 */
DrupalError.INVALID_EVENT_NAME = 160;
/**
 * Error code indicating that a field had an invalid value.
 */
DrupalError.INVALID_VALUE = 162;
/**
 * Error code indicating that the username is missing or empty.
 */
DrupalError.USERNAME_MISSING = 200;
/**
 * Error code indicating that the password is missing or empty.
 */
DrupalError.PASSWORD_MISSING = 201;
/**
 * Error code indicating that the username has already been taken.
 */
DrupalError.USERNAME_TAKEN = 202;
/**
 * Error code indicating that the email has already been taken.
 */
DrupalError.EMAIL_TAKEN = 203;
/**
 * Error code indicating that the email is missing, but must be specified.
 */
DrupalError.EMAIL_MISSING = 204;
/**
 * Error code indicating that a user with the specified email was not found.
 */
DrupalError.EMAIL_NOT_FOUND = 205;
/**
 * Error code indicating that a user object without a valid session could
 * not be altered.
 */
DrupalError.SESSION_MISSING = 206;
/**
 * Error code indicating that a user can only be created through signup.
 */
DrupalError.MUST_CREATE_USER_THROUGH_SIGNUP = 207;
/**
 * Error code indicating that an an account being linked is already linked
 * to another user.
 */
DrupalError.ACCOUNT_ALREADY_LINKED = 208;
/**
 * Error code indicating that the current session token is invalid.
 */
DrupalError.INVALID_SESSION_TOKEN = 209;
/**
 * Error code indicating an error enabling or verifying MFA
 */
DrupalError.MFA_ERROR = 210;
/**
 * Error code indicating that a valid MFA token must be provided
 */
DrupalError.MFA_TOKEN_REQUIRED = 211;
/**
 * Error code indicating that a user cannot be linked to an account because
 * that account's id could not be found.
 */
DrupalError.LINKED_ID_MISSING = 250;
/**
 * Error code indicating that a user with a linked (e.g. Facebook) account
 * has an invalid session.
 */
DrupalError.INVALID_LINKED_SESSION = 251;
/**
 * Error code indicating that a service being linked (e.g. Facebook or
 * Twitter) is unsupported.
 */
DrupalError.UNSUPPORTED_SERVICE = 252;
/**
 * Error code indicating an invalid operation occured on schema
 */
DrupalError.INVALID_SCHEMA_OPERATION = 255;
/**
 * Error code indicating that there were multiple errors. Aggregate errors
 * have an "errors" property, which is an array of error objects with more
 * detail about each error that occurred.
 */
DrupalError.AGGREGATE_ERROR = 600;
/**
 * Error code indicating the client was unable to read an input file.
 */
DrupalError.FILE_READ_ERROR = 601;
/**
 * Error code indicating a real error code is unavailable because
 * we had to use an XDomainRequest object to allow CORS requests in
 * Internet Explorer, which strips the body from HTTP responses that have
 * a non-2XX status code.
 */
DrupalError.X_DOMAIN_REQUEST = 602;
